@@ -14,26 +14,24 @@
 # See the README file for information on usage and redistribution.
 #
 
-from __future__ import print_function
 
 import os
+
 from . import Image, _binary
 
 WIDTH = 800
 
 
 def puti16(fp, values):
-    # write network order (big-endian) 16-bit sequence
+    """Write network order (big-endian) 16-bit sequence"""
     for v in values:
         if v < 0:
             v += 65536
         fp.write(_binary.o16be(v))
 
 
-##
-# Base class for raster font file handlers.
-
-class FontFile(object):
+class FontFile:
+    """Base class for raster font file handlers."""
 
     bitmap = None
 
@@ -46,7 +44,7 @@ class FontFile(object):
         return self.glyph[ix]
 
     def compile(self):
-        "Create metrics and bitmap"
+        """Create metrics and bitmap"""
 
         if self.bitmap:
             return
@@ -61,7 +59,7 @@ class FontFile(object):
                 w = w + (src[2] - src[0])
                 if w > WIDTH:
                     lines += 1
-                    w = (src[2] - src[0])
+                    w = src[2] - src[0]
                 maxwidth = max(maxwidth, w)
 
         xsize = maxwidth
@@ -93,7 +91,7 @@ class FontFile(object):
                 self.metrics[i] = d, dst, s
 
     def save(self, filename):
-        "Save font"
+        """Save font"""
 
         self.compile()
 
@@ -103,7 +101,7 @@ class FontFile(object):
         # font metrics
         with open(os.path.splitext(filename)[0] + ".pil", "wb") as fp:
             fp.write(b"PILfont\n")
-            fp.write((";;;;;;%d;\n" % self.ysize).encode('ascii'))  # HACK!!!
+            fp.write((";;;;;;%d;\n" % self.ysize).encode("ascii"))  # HACK!!!
             fp.write(b"DATA\n")
             for id in range(256):
                 m = self.metrics[id]
