@@ -15,18 +15,18 @@
 # See the README file for information on usage and redistribution.  See
 # below for the original description.
 
-from __future__ import print_function
 import sys
 
 from PIL import Image
+
 try:
     from PIL import _imagingcms
 except ImportError as ex:
     # Allow error import for doc purposes, but error out when accessing
     # anything in core.
-    from _util import deferred_error
+    from ._util import deferred_error
+
     _imagingcms = deferred_error(ex)
-from PIL._util import isStringType
 
 DESCRIPTION = """
 pyCMS
@@ -132,7 +132,7 @@ FLAGS = {
     "SOFTPROOFING": 16384,  # Do softproofing
     "PRESERVEBLACK": 32768,  # Black preservation
     "NODEFAULTRESOURCEDEF": 16777216,  # CRD special
-    "GRIDPOINTS": lambda n: ((n) & 0xFF) << 16  # Gridpoints
+    "GRIDPOINTS": lambda n: ((n) & 0xFF) << 16,  # Gridpoints
 }
 
 _MAX_FLAG = 0
@@ -148,8 +148,8 @@ for flag in FLAGS.values():
 ##
 # Profile.
 
-class ImageCmsProfile(object):
 
+class ImageCmsProfile:
     def __init__(self, profile):
         """
         :param profile: Either a string representing a filename,
@@ -158,7 +158,7 @@ class ImageCmsProfile(object):
 
         """
 
-        if isStringType(profile):
+        if isinstance(profile, str):
             self._set(core.profile_open(profile), profile)
         elif hasattr(profile, "read"):
             self._set(core.profile_frombytes(profile.read()))
@@ -192,27 +192,36 @@ class ImageCmsTransform(Image.ImagePointHandler):
 
     """
     Transform.  This can be used with the procedural API, or with the standard
-    Image.point() method.
+    :py:func:`~PIL.Image.Image.point` method.
 
-    Will return the output profile in the output.info['icc_profile'].
+    Will return the output profile in the ``output.info['icc_profile']``.
     """
 
-    def __init__(self, input, output, input_mode, output_mode,
-                 intent=INTENT_PERCEPTUAL, proof=None,
-                 proof_intent=INTENT_ABSOLUTE_COLORIMETRIC, flags=0):
+    def __init__(
+        self,
+        input,
+        output,
+        input_mode,
+        output_mode,
+        intent=INTENT_PERCEPTUAL,
+        proof=None,
+        proof_intent=INTENT_ABSOLUTE_COLORIMETRIC,
+        flags=0,
+    ):
         if proof is None:
             self.transform = core.buildTransform(
-                input.profile, output.profile,
-                input_mode, output_mode,
-                intent,
-                flags
+                input.profile, output.profile, input_mode, output_mode, intent, flags
             )
         else:
             self.transform = core.buildProofTransform(
-                input.profile, output.profile, proof.profile,
-                input_mode, output_mode,
-                intent, proof_intent,
-                flags
+                input.profile,
+                output.profile,
+                proof.profile,
+                input_mode,
+                output_mode,
+                intent,
+                proof_intent,
+                flags,
             )
         # Note: inputMode and outputMode are for pyCMS compatibility only
         self.input_mode = self.inputMode = input_mode
@@ -228,7 +237,7 @@ class ImageCmsTransform(Image.ImagePointHandler):
         if imOut is None:
             imOut = Image.new(self.output_mode, im.size, None)
         self.transform.apply(im.im.id, imOut.im.id)
-        imOut.info['icc_profile'] = self.output_profile.tobytes()
+        imOut.info["icc_profile"] = self.output_profile.tobytes()
         return imOut
 
     def apply_in_place(self, im):
@@ -236,28 +245,26 @@ class ImageCmsTransform(Image.ImagePointHandler):
         if im.mode != self.output_mode:
             raise ValueError("mode mismatch")  # wrong output mode
         self.transform.apply(im.im.id, im.im.id)
-        im.info['icc_profile'] = self.output_profile.tobytes()
+        im.info["icc_profile"] = self.output_profile.tobytes()
         return im
 
 
 def get_display_profile(handle=None):
     """ (experimental) Fetches the profile for the current display device.
-    :returns: None if the profile is not known.
+    :returns: ``None`` if the profile is not known.
     """
 
-    if sys.platform == "win32":
-        from PIL import ImageWin
-        if isinstance(handle, ImageWin.HDC):
-            profile = core.get_display_profile_win32(handle, 1)
-        else:
-            profile = core.get_display_profile_win32(handle or 0)
+    if sys.platform != "win32":
+        return None
+
+    from PIL import ImageWin
+
+    if isinstance(handle, ImageWin.HDC):
+        profile = core.get_display_profile_win32(handle, 1)
     else:
-        try:
-            get = _imagingcms.get_display_profile
-        except AttributeError:
-            return None
-        else:
-            profile = get()
+        profile = core.get_display_profile_win32(handle or 0)
+    if profile is None:
+        return None
     return ImageCmsProfile(profile)
 
 
@@ -265,39 +272,48 @@ def get_display_profile(handle=None):
 # pyCMS compatible layer
 # --------------------------------------------------------------------.
 
+
 class PyCMSError(Exception):
 
     """ (pyCMS) Exception class.
     This is used for all errors in the pyCMS API. """
+
     pass
 
 
 def profileToProfile(
-        im, inputProfile, outputProfile, renderingIntent=INTENT_PERCEPTUAL,
-        outputMode=None, inPlace=False, flags=0):
+    im,
+    inputProfile,
+    outputProfile,
+    renderingIntent=INTENT_PERCEPTUAL,
+    outputMode=None,
+    inPlace=False,
+    flags=0,
+):
     """
     (pyCMS) Applies an ICC transformation to a given image, mapping from
-    inputProfile to outputProfile.
+    ``inputProfile`` to ``outputProfile``.
 
     If the input or output profiles specified are not valid filenames, a
-    PyCMSError will be raised.  If inPlace is True and outputMode != im.mode,
-    a PyCMSError will be raised.  If an error occurs during application of
-    the profiles, a PyCMSError will be raised.  If outputMode is not a mode
-    supported by the outputProfile (or by pyCMS), a PyCMSError will be
-    raised.
+    :exc:`PyCMSError` will be raised.  If ``inPlace`` is ``True`` and
+    ``outputMode != im.mode``, a :exc:`PyCMSError` will be raised.
+    If an error occurs during application of the profiles,
+    a :exc:`PyCMSError` will be raised.
+    If ``outputMode`` is not a mode supported by the ``outputProfile`` (or by pyCMS),
+    a :exc:`PyCMSError` will be raised.
 
-    This function applies an ICC transformation to im from inputProfile's
-    color space to outputProfile's color space using the specified rendering
+    This function applies an ICC transformation to im from ``inputProfile``'s
+    color space to ``outputProfile``'s color space using the specified rendering
     intent to decide how to handle out-of-gamut colors.
 
-    OutputMode can be used to specify that a color mode conversion is to
+    ``outputMode`` can be used to specify that a color mode conversion is to
     be done using these profiles, but the specified profiles must be able
     to handle that mode.  I.e., if converting im from RGB to CMYK using
     profiles, the input profile must handle RGB data, and the output
     profile must handle CMYK data.
 
-    :param im: An open PIL image object (i.e. Image.new(...) or
-        Image.open(...), etc.)
+    :param im: An open :py:class:`~PIL.Image.Image` object (i.e. Image.new(...)
+        or Image.open(...), etc.)
     :param inputProfile: String, as a valid filename path to the ICC input
         profile you wish to use for this image, or a profile object
     :param outputProfile: String, as a valid filename path to the ICC output
@@ -317,12 +333,12 @@ def profileToProfile(
         MUST be the same mode as the input, or omitted completely.  If
         omitted, the outputMode will be the same as the mode of the input
         image (im.mode)
-    :param inPlace: Boolean.  If True, the original image is modified in-place,
-        and None is returned.  If False (default), a new Image object is
-        returned with the transform applied.
+    :param inPlace: Boolean.  If ``True``, the original image is modified in-place,
+        and ``None`` is returned.  If ``False`` (default), a new
+        :py:class:`~PIL.Image.Image` object is returned with the transform applied.
     :param flags: Integer (0-...) specifying additional flags
-    :returns: Either None or a new PIL image object, depending on value of
-        inPlace
+    :returns: Either None or a new :py:class:`~PIL.Image.Image` object, depending on
+        the value of ``inPlace``
     :exception PyCMSError:
     """
 
@@ -333,8 +349,7 @@ def profileToProfile(
         raise PyCMSError("renderingIntent must be an integer between 0 and 3")
 
     if not isinstance(flags, int) or not (0 <= flags <= _MAX_FLAG):
-        raise PyCMSError(
-            "flags must be an integer between 0 and %s" + _MAX_FLAG)
+        raise PyCMSError("flags must be an integer between 0 and %s" + _MAX_FLAG)
 
     try:
         if not isinstance(inputProfile, ImageCmsProfile):
@@ -342,16 +357,20 @@ def profileToProfile(
         if not isinstance(outputProfile, ImageCmsProfile):
             outputProfile = ImageCmsProfile(outputProfile)
         transform = ImageCmsTransform(
-            inputProfile, outputProfile, im.mode, outputMode,
-            renderingIntent, flags=flags
+            inputProfile,
+            outputProfile,
+            im.mode,
+            outputMode,
+            renderingIntent,
+            flags=flags,
         )
         if inPlace:
             transform.apply_in_place(im)
             imOut = None
         else:
             imOut = transform.apply(im)
-    except (IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
     return imOut
 
@@ -363,8 +382,8 @@ def getOpenProfile(profileFilename):
     The PyCMSProfile object can be passed back into pyCMS for use in creating
     transforms and such (as in ImageCms.buildTransformFromOpenProfiles()).
 
-    If profileFilename is not a valid filename for an ICC profile, a PyCMSError
-    will be raised.
+    If ``profileFilename`` is not a valid filename for an ICC profile,
+    a :exc:`PyCMSError` will be raised.
 
     :param profileFilename: String, as a valid filename path to the ICC profile
         you wish to open, or a file-like object.
@@ -374,29 +393,34 @@ def getOpenProfile(profileFilename):
 
     try:
         return ImageCmsProfile(profileFilename)
-    except (IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def buildTransform(
-        inputProfile, outputProfile, inMode, outMode,
-        renderingIntent=INTENT_PERCEPTUAL, flags=0):
+    inputProfile,
+    outputProfile,
+    inMode,
+    outMode,
+    renderingIntent=INTENT_PERCEPTUAL,
+    flags=0,
+):
     """
-    (pyCMS) Builds an ICC transform mapping from the inputProfile to the
-    outputProfile.  Use applyTransform to apply the transform to a given
+    (pyCMS) Builds an ICC transform mapping from the ``inputProfile`` to the
+    ``outputProfile``. Use applyTransform to apply the transform to a given
     image.
 
     If the input or output profiles specified are not valid filenames, a
-    PyCMSError will be raised.  If an error occurs during creation of the
-    transform, a PyCMSError will be raised.
+    :exc:`PyCMSError` will be raised. If an error occurs during creation
+    of the transform, a :exc:`PyCMSError` will be raised.
 
-    If inMode or outMode are not a mode supported by the outputProfile (or
-    by pyCMS), a PyCMSError will be raised.
+    If ``inMode`` or ``outMode`` are not a mode supported by the ``outputProfile``
+    (or by pyCMS), a :exc:`PyCMSError` will be raised.
 
-    This function builds and returns an ICC transform from the inputProfile
-    to the outputProfile using the renderingIntent to determine what to do
+    This function builds and returns an ICC transform from the ``inputProfile``
+    to the ``outputProfile`` using the ``renderingIntent`` to determine what to do
     with out-of-gamut colors.  It will ONLY work for converting images that
-    are in inMode to images that are in outMode color format (PIL mode,
+    are in ``inMode`` to images that are in ``outMode`` color format (PIL mode,
     i.e. "RGB", "RGBA", "CMYK", etc.).
 
     Building the transform is a fair part of the overhead in
@@ -409,7 +433,7 @@ def buildTransform(
     The reason pyCMS returns a class object rather than a handle directly
     to the transform is that it needs to keep track of the PIL input/output
     modes that the transform is meant for.  These attributes are stored in
-    the "inMode" and "outMode" attributes of the object (which can be
+    the ``inMode`` and ``outMode`` attributes of the object (which can be
     manually overridden if you really want to, but I don't know of any
     time that would be of use, or would even work).
 
@@ -440,8 +464,7 @@ def buildTransform(
         raise PyCMSError("renderingIntent must be an integer between 0 and 3")
 
     if not isinstance(flags, int) or not (0 <= flags <= _MAX_FLAG):
-        raise PyCMSError(
-            "flags must be an integer between 0 and %s" + _MAX_FLAG)
+        raise PyCMSError("flags must be an integer between 0 and %s" + _MAX_FLAG)
 
     try:
         if not isinstance(inputProfile, ImageCmsProfile):
@@ -449,37 +472,42 @@ def buildTransform(
         if not isinstance(outputProfile, ImageCmsProfile):
             outputProfile = ImageCmsProfile(outputProfile)
         return ImageCmsTransform(
-            inputProfile, outputProfile, inMode, outMode,
-            renderingIntent, flags=flags)
-    except (IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+            inputProfile, outputProfile, inMode, outMode, renderingIntent, flags=flags
+        )
+    except (OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def buildProofTransform(
-        inputProfile, outputProfile, proofProfile, inMode, outMode,
-        renderingIntent=INTENT_PERCEPTUAL,
-        proofRenderingIntent=INTENT_ABSOLUTE_COLORIMETRIC,
-        flags=FLAGS["SOFTPROOFING"]):
+    inputProfile,
+    outputProfile,
+    proofProfile,
+    inMode,
+    outMode,
+    renderingIntent=INTENT_PERCEPTUAL,
+    proofRenderingIntent=INTENT_ABSOLUTE_COLORIMETRIC,
+    flags=FLAGS["SOFTPROOFING"],
+):
     """
-    (pyCMS) Builds an ICC transform mapping from the inputProfile to the
-    outputProfile, but tries to simulate the result that would be
-    obtained on the proofProfile device.
+    (pyCMS) Builds an ICC transform mapping from the ``inputProfile`` to the
+    ``outputProfile``, but tries to simulate the result that would be
+    obtained on the ``proofProfile`` device.
 
     If the input, output, or proof profiles specified are not valid
-    filenames, a PyCMSError will be raised.
+    filenames, a :exc:`PyCMSError` will be raised.
 
-    If an error occurs during creation of the transform, a PyCMSError will
-    be raised.
+    If an error occurs during creation of the transform,
+    a :exc:`PyCMSError` will be raised.
 
-    If inMode or outMode are not a mode supported by the outputProfile
-    (or by pyCMS), a PyCMSError will be raised.
+    If ``inMode`` or ``outMode`` are not a mode supported by the ``outputProfile``
+    (or by pyCMS), a :exc:`PyCMSError` will be raised.
 
-    This function builds and returns an ICC transform from the inputProfile
-    to the outputProfile, but tries to simulate the result that would be
-    obtained on the proofProfile device using renderingIntent and
-    proofRenderingIntent to determine what to do with out-of-gamut
+    This function builds and returns an ICC transform from the ``inputProfile``
+    to the ``outputProfile``, but tries to simulate the result that would be
+    obtained on the ``proofProfile`` device using ``renderingIntent`` and
+    ``proofRenderingIntent`` to determine what to do with out-of-gamut
     colors.  This is known as "soft-proofing".  It will ONLY work for
-    converting images that are in inMode to images that are in outMode
+    converting images that are in ``inMode`` to images that are in outMode
     color format (PIL mode, i.e. "RGB", "RGBA", "CMYK", etc.).
 
     Usage of the resulting transform object is exactly the same as with
@@ -487,7 +515,7 @@ def buildProofTransform(
 
     Proof profiling is generally used when using an output device to get a
     good idea of what the final printed/displayed image would look like on
-    the proofProfile device when it's quicker and easier to use the
+    the ``proofProfile`` device when it's quicker and easier to use the
     output device for judging color.  Generally, this means that the
     output device is a monitor, or a dye-sub printer (etc.), and the simulated
     device is something more expensive, complicated, or time consuming
@@ -538,8 +566,7 @@ def buildProofTransform(
         raise PyCMSError("renderingIntent must be an integer between 0 and 3")
 
     if not isinstance(flags, int) or not (0 <= flags <= _MAX_FLAG):
-        raise PyCMSError(
-            "flags must be an integer between 0 and %s" + _MAX_FLAG)
+        raise PyCMSError("flags must be an integer between 0 and %s" + _MAX_FLAG)
 
     try:
         if not isinstance(inputProfile, ImageCmsProfile):
@@ -549,10 +576,17 @@ def buildProofTransform(
         if not isinstance(proofProfile, ImageCmsProfile):
             proofProfile = ImageCmsProfile(proofProfile)
         return ImageCmsTransform(
-            inputProfile, outputProfile, inMode, outMode, renderingIntent,
-            proofProfile, proofRenderingIntent, flags)
-    except (IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+            inputProfile,
+            outputProfile,
+            inMode,
+            outMode,
+            renderingIntent,
+            proofProfile,
+            proofRenderingIntent,
+            flags,
+        )
+    except (OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 buildTransformFromOpenProfiles = buildTransform
@@ -563,39 +597,40 @@ def applyTransform(im, transform, inPlace=False):
     """
     (pyCMS) Applies a transform to a given image.
 
-    If im.mode != transform.inMode, a PyCMSError is raised.
+    If ``im.mode != transform.inMode``, a :exc:`PyCMSError` is raised.
 
-    If inPlace is True and transform.inMode != transform.outMode, a
-    PyCMSError is raised.
+    If ``inPlace`` is ``True`` and ``transform.inMode != transform.outMode``, a
+    :exc:`PyCMSError` is raised.
 
-    If im.mode, transfer.inMode, or transfer.outMode is not supported by
-    pyCMSdll or the profiles you used for the transform, a PyCMSError is
-    raised.
+    If ``im.mode``, ``transform.inMode`` or ``transform.outMode`` is not
+    supported by pyCMSdll or the profiles you used for the transform, a
+    :exc:`PyCMSError` is raised.
 
-    If an error occurs while the transform is being applied, a PyCMSError
-    is raised.
+    If an error occurs while the transform is being applied,
+    a :exc:`PyCMSError` is raised.
 
     This function applies a pre-calculated transform (from
     ImageCms.buildTransform() or ImageCms.buildTransformFromOpenProfiles())
-    to an image.  The transform can be used for multiple images, saving
+    to an image. The transform can be used for multiple images, saving
     considerable calculation time if doing the same conversion multiple times.
 
     If you want to modify im in-place instead of receiving a new image as
-    the return value, set inPlace to True.  This can only be done if
-    transform.inMode and transform.outMode are the same, because we can't
+    the return value, set ``inPlace`` to ``True``.  This can only be done if
+    ``transform.inMode`` and ``transform.outMode`` are the same, because we can't
     change the mode in-place (the buffer sizes for some modes are
-    different).  The  default behavior is to return a new Image object of
-    the same dimensions in mode transform.outMode.
+    different).  The default behavior is to return a new :py:class:`~PIL.Image.Image`
+    object of the same dimensions in mode ``transform.outMode``.
 
-    :param im: A PIL Image object, and im.mode must be the same as the inMode
-        supported by the transform.
+    :param im: An :py:class:`~PIL.Image.Image` object, and im.mode must be the same
+        as the ``inMode`` supported by the transform.
     :param transform: A valid CmsTransform class object
-    :param inPlace: Bool.  If True, im is modified in place and None is
-        returned, if False, a new Image object with the transform applied is
-        returned (and im is not changed). The default is False.
-    :returns: Either None, or a new PIL Image object, depending on the value of
-        inPlace. The profile will be returned in the image's
-        info['icc_profile'].
+    :param inPlace: Bool.  If ``True``, ``im` is modified in place and ``None`` is
+        returned, if ``False``, a new :py:class:`~PIL.Image.Image` object with the
+        transform applied is returned (and ``im`` is not changed). The default is
+        ``False``.
+    :returns: Either ``None``, or a new :py:class:`~PIL.Image.Image` object,
+        depending on the value of ``inPlace``. The profile will be returned in
+        the image's ``info['icc_profile']``.
     :exception PyCMSError:
     """
 
@@ -606,7 +641,7 @@ def applyTransform(im, transform, inPlace=False):
         else:
             imOut = transform.apply(im)
     except (TypeError, ValueError) as v:
-        raise PyCMSError(v)
+        raise PyCMSError(v) from v
 
     return imOut
 
@@ -615,11 +650,14 @@ def createProfile(colorSpace, colorTemp=-1):
     """
     (pyCMS) Creates a profile.
 
-    If colorSpace not in ["LAB", "XYZ", "sRGB"], a PyCMSError is raised
+    If colorSpace not in ``["LAB", "XYZ", "sRGB"]``,
+    a :exc:`PyCMSError` is raised.
 
-    If using LAB and colorTemp != a positive integer, a PyCMSError is raised.
+    If using LAB and ``colorTemp`` is not a positive integer,
+    a :exc:`PyCMSError` is raised.
 
-    If an error occurs while creating the profile, a PyCMSError is raised.
+    If an error occurs while creating the profile,
+    a :exc:`PyCMSError` is raised.
 
     Use this function to create common profiles on-the-fly instead of
     having to supply a profile on disk and knowing the path to it.  It
@@ -641,20 +679,21 @@ def createProfile(colorSpace, colorTemp=-1):
     if colorSpace not in ["LAB", "XYZ", "sRGB"]:
         raise PyCMSError(
             "Color space not supported for on-the-fly profile creation (%s)"
-            % colorSpace)
+            % colorSpace
+        )
 
     if colorSpace == "LAB":
         try:
             colorTemp = float(colorTemp)
-        except (TypeError, ValueError):
+        except (TypeError, ValueError) as e:
             raise PyCMSError(
-                "Color temperature must be numeric, \"%s\" not valid"
-                % colorTemp)
+                'Color temperature must be numeric, "%s" not valid' % colorTemp
+            ) from e
 
     try:
         return core.createProfile(colorSpace, colorTemp)
     except (TypeError, ValueError) as v:
-        raise PyCMSError(v)
+        raise PyCMSError(v) from v
 
 
 def getProfileName(profile):
@@ -662,9 +701,9 @@ def getProfileName(profile):
 
     (pyCMS) Gets the internal product name for the given profile.
 
-    If profile isn't a valid CmsProfile object or filename to a profile,
-    a PyCMSError is raised If an error occurs while trying to obtain the
-    name tag, a PyCMSError is raised.
+    If ``profile`` isn't a valid CmsProfile object or filename to a profile,
+    a :exc:`PyCMSError` is raised If an error occurs while trying
+    to obtain the name tag, a :exc:`PyCMSError` is raised.
 
     Use this function to obtain the INTERNAL name of the profile (stored
     in an ICC tag in the profile itself), usually the one used when the
@@ -693,21 +732,21 @@ def getProfileName(profile):
             return (profile.profile.profile_description or "") + "\n"
         if not manufacturer or len(model) > 30:
             return model + "\n"
-        return "%s - %s\n" % (model, manufacturer)
+        return "{} - {}\n".format(model, manufacturer)
 
-    except (AttributeError, IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (AttributeError, OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def getProfileInfo(profile):
     """
     (pyCMS) Gets the internal product information for the given profile.
 
-    If profile isn't a valid CmsProfile object or filename to a profile,
-    a PyCMSError is raised.
+    If ``profile`` isn't a valid CmsProfile object or filename to a profile,
+    a :exc:`PyCMSError` is raised.
 
-    If an error occurs while trying to obtain the info tag, a PyCMSError
-    is raised
+    If an error occurs while trying to obtain the info tag,
+    a :exc:`PyCMSError` is raised.
 
     Use this function to obtain the information stored in the profile's
     info tag.  This often contains details about the profile, and how it
@@ -735,19 +774,19 @@ def getProfileInfo(profile):
                 arr.append(elt)
         return "\r\n\r\n".join(arr) + "\r\n\r\n"
 
-    except (AttributeError, IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (AttributeError, OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def getProfileCopyright(profile):
     """
     (pyCMS) Gets the copyright for the given profile.
 
-    If profile isn't a valid CmsProfile object or filename to a profile,
-    a PyCMSError is raised.
+    If ``profile`` isn't a valid CmsProfile object or filename to a profile, a
+    :exc:`PyCMSError` is raised.
 
-    If an error occurs while trying to obtain the copyright tag, a PyCMSError
-    is raised
+    If an error occurs while trying to obtain the copyright tag,
+    a :exc:`PyCMSError` is raised.
 
     Use this function to obtain the information stored in the profile's
     copyright tag.
@@ -763,19 +802,19 @@ def getProfileCopyright(profile):
         if not isinstance(profile, ImageCmsProfile):
             profile = ImageCmsProfile(profile)
         return (profile.profile.copyright or "") + "\n"
-    except (AttributeError, IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (AttributeError, OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def getProfileManufacturer(profile):
     """
     (pyCMS) Gets the manufacturer for the given profile.
 
-    If profile isn't a valid CmsProfile object or filename to a profile,
-    a PyCMSError is raised.
+    If ``profile`` isn't a valid CmsProfile object or filename to a profile, a
+    :exc:`PyCMSError` is raised.
 
     If an error occurs while trying to obtain the manufacturer tag, a
-    PyCMSError is raised
+    :exc:`PyCMSError` is raised.
 
     Use this function to obtain the information stored in the profile's
     manufacturer tag.
@@ -791,19 +830,19 @@ def getProfileManufacturer(profile):
         if not isinstance(profile, ImageCmsProfile):
             profile = ImageCmsProfile(profile)
         return (profile.profile.manufacturer or "") + "\n"
-    except (AttributeError, IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (AttributeError, OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def getProfileModel(profile):
     """
     (pyCMS) Gets the model for the given profile.
 
-    If profile isn't a valid CmsProfile object or filename to a profile,
-    a PyCMSError is raised.
+    If ``profile`` isn't a valid CmsProfile object or filename to a profile, a
+    :exc:`PyCMSError` is raised.
 
-    If an error occurs while trying to obtain the model tag, a PyCMSError
-    is raised
+    If an error occurs while trying to obtain the model tag,
+    a :exc:`PyCMSError` is raised.
 
     Use this function to obtain the information stored in the profile's
     model tag.
@@ -820,19 +859,19 @@ def getProfileModel(profile):
         if not isinstance(profile, ImageCmsProfile):
             profile = ImageCmsProfile(profile)
         return (profile.profile.model or "") + "\n"
-    except (AttributeError, IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (AttributeError, OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def getProfileDescription(profile):
     """
     (pyCMS) Gets the description for the given profile.
 
-    If profile isn't a valid CmsProfile object or filename to a profile,
-    a PyCMSError is raised.
+    If ``profile`` isn't a valid CmsProfile object or filename to a profile, a
+    :exc:`PyCMSError` is raised.
 
-    If an error occurs while trying to obtain the description tag, a PyCMSError
-    is raised
+    If an error occurs while trying to obtain the description tag,
+    a :exc:`PyCMSError` is raised.
 
     Use this function to obtain the information stored in the profile's
     description tag.
@@ -849,19 +888,19 @@ def getProfileDescription(profile):
         if not isinstance(profile, ImageCmsProfile):
             profile = ImageCmsProfile(profile)
         return (profile.profile.profile_description or "") + "\n"
-    except (AttributeError, IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (AttributeError, OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def getDefaultIntent(profile):
     """
     (pyCMS) Gets the default intent name for the given profile.
 
-    If profile isn't a valid CmsProfile object or filename to a profile,
-    a PyCMSError is raised.
+    If ``profile`` isn't a valid CmsProfile object or filename to a profile, a
+    :exc:`PyCMSError` is raised.
 
     If an error occurs while trying to obtain the default intent, a
-    PyCMSError is raised.
+    :exc:`PyCMSError` is raised.
 
     Use this function to determine the default (and usually best optimized)
     rendering intent for this profile.  Most profiles support multiple
@@ -888,8 +927,8 @@ def getDefaultIntent(profile):
         if not isinstance(profile, ImageCmsProfile):
             profile = ImageCmsProfile(profile)
         return profile.profile.rendering_intent
-    except (AttributeError, IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (AttributeError, OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def isIntentSupported(profile, intent, direction):
@@ -897,15 +936,15 @@ def isIntentSupported(profile, intent, direction):
     (pyCMS) Checks if a given intent is supported.
 
     Use this function to verify that you can use your desired
-    renderingIntent with profile, and that profile can be used for the
+    ``intent`` with ``profile``, and that ``profile`` can be used for the
     input/output/proof profile as you desire.
 
     Some profiles are created specifically for one "direction", can cannot
-    be used for others.  Some profiles can only be used for certain
-    rendering intents... so it's best to either verify this before trying
+    be used for others. Some profiles can only be used for certain
+    rendering intents, so it's best to either verify this before trying
     to create a transform with them (using this function), or catch the
-    potential PyCMSError that will occur if they don't support the modes
-    you select.
+    potential :exc:`PyCMSError` that will occur if they don't
+    support the modes you select.
 
     :param profile: EITHER a valid CmsProfile object, OR a string of the
         filename of an ICC profile.
@@ -939,8 +978,8 @@ def isIntentSupported(profile, intent, direction):
             return 1
         else:
             return -1
-    except (AttributeError, IOError, TypeError, ValueError) as v:
-        raise PyCMSError(v)
+    except (AttributeError, OSError, TypeError, ValueError) as v:
+        raise PyCMSError(v) from v
 
 
 def versions():
@@ -948,7 +987,4 @@ def versions():
     (pyCMS) Fetches versions.
     """
 
-    return (
-        VERSION, core.littlecms_version,
-        sys.version.split()[0], Image.__version__
-    )
+    return (VERSION, core.littlecms_version, sys.version.split()[0], Image.__version__)
